==> client-java-api-9.0.2-sources.jar: io/kubernetes/client/openapi/models/V1CustomResourceDefinitionVersionFluent.java <==
package io.kubernetes.client.openapi.models;

import io.kubernetes.client.fluent.VisitableBuilder;
import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.kubernetes.client.fluent.Fluent;
import java.lang.StringBuffer;
import java.util.Collection;

public interface V1CustomResourceDefinitionVersionFluent<A extends V1CustomResourceDefinitionVersionFluent<A>> extends Fluent<A>{


    public A addToAdditionalPrinterColumns(int index,V1CustomResourceColumnDefinition item);
    public A setToAdditionalPrinterColumns(int index,V1CustomResourceColumnDefinition item);
    public A addToAdditionalPrinterColumns(V1CustomResourceColumnDefinition... items);
    public A addAllToAdditionalPrinterColumns(Collection<V1CustomResourceColumnDefinition> items);
    public A removeFromAdditionalPrinterColumns(V1CustomResourceColumnDefinition... items);
    public A removeAllFromAdditionalPrinterColumns(Collection<V1CustomResourceColumnDefinition> items);
    public A removeMatchingFromAdditionalPrinterColumns(io.kubernetes.client.fluent.Predicate<V1CustomResourceColumnDefinitionBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildAdditionalPrinterColumns instead.
 * @return The buildable object.
 */
@Deprecated public List<V1CustomResourceColumnDefinition> getAdditionalPrinterColumns();
    public List<V1CustomResourceColumnDefinition> buildAdditionalPrinterColumns();
    public V1CustomResourceColumnDefinition buildAdditionalPrinterColumn(int index);
    public V1CustomResourceColumnDefinition buildFirstAdditionalPrinterColumn();
    public V1CustomResourceColumnDefinition buildLastAdditionalPrinterColumn();
    public V1CustomResourceColumnDefinition buildMatchingAdditionalPrinterColumn(io.kubernetes.client.fluent.Predicate<V1CustomResourceColumnDefinitionBuilder> predicate);
    public Boolean hasMatchingAdditionalPrinterColumn(io.kubernetes.client.fluent.Predicate<V1CustomResourceColumnDefinitionBuilder> predicate);
    public A withAdditionalPrinterColumns(List<V1CustomResourceColumnDefinition> additionalPrinterColumns);
    public A withAdditionalPrinterColumns(V1CustomResourceColumnDefinition... additionalPrinterColumns);
    public Boolean hasAdditionalPrinterColumns();
    public V1CustomResourceDefinitionVersionFluent.AdditionalPrinterColumnsNested<A> addNewAdditionalPrinterColumn();
    public V1CustomResourceDefinitionVersionFluent.AdditionalPrinterColumnsNested<A> addNewAdditionalPrinterColumnLike(V1CustomResourceColumnDefinition item);
    public V1CustomResourceDefinitionVersionFluent.AdditionalPrinterColumnsNested<A> setNewAdditionalPrinterColumnLike(int index,V1CustomResourceColumnDefinition item);
    public V1CustomResourceDefinitionVersionFluent.AdditionalPrinterColumnsNested<A> editAdditionalPrinterColumn(int index);
    public V1CustomResourceDefinitionVersionFluent.AdditionalPrinterColumnsNested<A> editFirstAdditionalPrinterColumn();
    public V1CustomResourceDefinitionVersionFluent.AdditionalPrinterColumnsNested<A> editLastAdditionalPrinterColumn();
    public V1CustomResourceDefinitionVersionFluent.AdditionalPrinterColumnsNested<A> editMatchingAdditionalPrinterColumn(io.kubernetes.client.fluent.Predicate<V1CustomResourceColumnDefinitionBuilder> predicate);
    public String getName();
    public A withName(String name);
    public Boolean hasName();
    public A withNewName(String arg1);
    public A withNewName(StringBuilder arg1);
    public A withNewName(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildSchema instead.
 * @return The buildable object.
 */
@Deprecated public V1CustomResourceValidation getSchema();
    public V1CustomResourceValidation buildSchema();
    public A withSchema(V1CustomResourceValidation schema);
    public Boolean hasSchema();
    public V1CustomResourceDefinitionVersionFluent.SchemaNested<A> withNewSchema();
    public V1CustomResourceDefinitionVersionFluent.SchemaNested<A> withNewSchemaLike(V1CustomResourceValidation item);
    public V1CustomResourceDefinitionVersionFluent.SchemaNested<A> editSchema();
    public V1CustomResourceDefinitionVersionFluent.SchemaNested<A> editOrNewSchema();
    public V1CustomResourceDefinitionVersionFluent.SchemaNested<A> editOrNewSchemaLike(V1CustomResourceValidation item);
    public Boolean isServed();
    public A withServed(Boolean served);
    public Boolean hasServed();
    public A withNewServed(String arg1);
    public A withNewServed(boolean arg1);
    public Boolean isStorage();
    public A withStorage(Boolean storage);
    public Boolean hasStorage();
    public A withNewStorage(String arg1);
    public A withNewStorage(boolean arg1);
    
/**
 * This method has been deprecated, please use method buildSubresources instead.
 * @return The buildable object.
 */
@Deprecated public V1CustomResourceSubresources getSubresources();
    public V1CustomResourceSubresources buildSubresources();
    public A withSubresources(V1CustomResourceSubresources subresources);
    public Boolean hasSubresources();
    public V1CustomResourceDefinitionVersionFluent.SubresourcesNested<A> withNewSubresources();
    public V1CustomResourceDefinitionVersionFluent.SubresourcesNested<A> withNewSubresourcesLike(V1CustomResourceSubresources item);
    public V1CustomResourceDefinitionVersionFluent.SubresourcesNested<A> editSubresources();
    public V1CustomResourceDefinitionVersionFluent.SubresourcesNested<A> editOrNewSubresources();
    public V1CustomResourceDefinitionVersionFluent.SubresourcesNested<A> editOrNewSubresourcesLike(V1CustomResourceSubresources item);

    public interface AdditionalPrinterColumnsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1CustomResourceColumnDefinitionFluent<V1CustomResourceDefinitionVersionFluent.AdditionalPrinterColumnsNested<N>>{

        
    public N and();    public N endAdditionalPrinterColumn();
}
    public interface SchemaNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1CustomResourceValidationFluent<V1CustomResourceDefinitionVersionFluent.SchemaNested<N>>{

        
    public N and();    public N endSchema();
}
    public interface SubresourcesNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1CustomResourceSubresourcesFluent<V1CustomResourceDefinitionVersionFluent.SubresourcesNested<N>>{

        
    public N and();    public N endSubresources();
}


}

==> client-java-api-11.0.4-sources.jar: io/kubernetes/client/openapi/models/V1CustomResourceDefinitionVersionFluent.java <==
package io.kubernetes.client.openapi.models;

import io.kubernetes.client.fluent.VisitableBuilder;
import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.kubernetes.client.fluent.Fluent;
import java.lang.StringBuffer;
import java.util.Collection;

public interface V1CustomResourceDefinitionVersionFluent<A extends V1CustomResourceDefinitionVersionFluent<A>> extends Fluent<A> {


    public A addToAdditionalPrinterColumns(int index,V1CustomResourceColumnDefinition item);
    public A setToAdditionalPrinterColumns(int index,V1CustomResourceColumnDefinition item);
    public A addToAdditionalPrinterColumns(V1CustomResourceColumnDefinition... items);
    public A addAllToAdditionalPrinterColumns(Collection<V1CustomResourceColumnDefinition> items);
    public A removeFromAdditionalPrinterColumns(V1CustomResourceColumnDefinition... items);
    public A removeAllFromAdditionalPrinterColumns(Collection<V1CustomResourceColumnDefinition> items);
    public A removeMatchingFromAdditionalPrinterColumns(io.kubernetes.client.fluent.Predicate<V1CustomResourceColumnDefinitionBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildAdditionalPrinterColumns instead.
 * @return The buildable object.
 */
@Deprecated public List<V1CustomResourceColumnDefinition> getAdditionalPrinterColumns();
    public List<V1CustomResourceColumnDefinition> buildAdditionalPrinterColumns();
    public V1CustomResourceColumnDefinition buildAdditionalPrinterColumn(int index);
    public V1CustomResourceColumnDefinition buildFirstAdditionalPrinterColumn();
    public V1CustomResourceColumnDefinition buildLastAdditionalPrinterColumn();
    public V1CustomResourceColumnDefinition buildMatchingAdditionalPrinterColumn(io.kubernetes.client.fluent.Predicate<V1CustomResourceColumnDefinitionBuilder> predicate);
    public Boolean hasMatchingAdditionalPrinterColumn(io.kubernetes.client.fluent.Predicate<V1CustomResourceColumnDefinitionBuilder> predicate);
    public A withAdditionalPrinterColumns(List<V1CustomResourceColumnDefinition> additionalPrinterColumns);
    public A withAdditionalPrinterColumns(V1CustomResourceColumnDefinition... additionalPrinterColumns);
    public Boolean hasAdditionalPrinterColumns();
    public V1CustomResourceDefinitionVersionFluent.AdditionalPrinterColumnsNested<A> addNewAdditionalPrinterColumn();
    public V1CustomResourceDefinitionVersionFluent.AdditionalPrinterColumnsNested<A> addNewAdditionalPrinterColumnLike(V1CustomResourceColumnDefinition item);
    public V1CustomResourceDefinitionVersionFluent.AdditionalPrinterColumnsNested<A> setNewAdditionalPrinterColumnLike(int index,V1CustomResourceColumnDefinition item);
    public V1CustomResourceDefinitionVersionFluent.AdditionalPrinterColumnsNested<A> editAdditionalPrinterColumn(int index);
    public V1CustomResourceDefinitionVersionFluent.AdditionalPrinterColumnsNested<A> editFirstAdditionalPrinterColumn();
    public V1CustomResourceDefinitionVersionFluent.AdditionalPrinterColumnsNested<A> editLastAdditionalPrinterColumn();
    public V1CustomResourceDefinitionVersionFluent.AdditionalPrinterColumnsNested<A> editMatchingAdditionalPrinterColumn(io.kubernetes.client.fluent.Predicate<V1CustomResourceColumnDefinitionBuilder> predicate);
    public Boolean isDeprecated();
    public A withDeprecated(Boolean deprecated);
    public Boolean hasDeprecated();
    public A withNewDeprecated(String arg1);
    public A withNewDeprecated(boolean arg1);
    public String getDeprecationWarning();
    public A withDeprecationWarning(String deprecationWarning);
    public Boolean hasDeprecationWarning();
    public A withNewDeprecationWarning(String arg1);
    public A withNewDeprecationWarning(StringBuilder arg1);
    public A withNewDeprecationWarning(StringBuffer arg1);
    public String getName();
    public A withName(String name);
    public Boolean hasName();
    public A withNewName(String arg1);
    public A withNewName(StringBuilder arg1);
    public A withNewName(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildSchema instead.
 * @return The buildable object.
 */
@Deprecated public V1CustomResourceValidation getSchema();
    public V1CustomResourceValidation buildSchema();
    public A withSchema(V1CustomResourceValidation schema);
    public Boolean hasSchema();
    public V1CustomResourceDefinitionVersionFluent.SchemaNested<A> withNewSchema();
    public V1CustomResourceDefinitionVersionFluent.SchemaNested<A> withNewSchemaLike(V1CustomResourceValidation item);
    public V1CustomResourceDefinitionVersionFluent.SchemaNested<A> editSchema();
    public V1CustomResourceDefinitionVersionFluent.SchemaNested<A> editOrNewSchema();
    public V1CustomResourceDefinitionVersionFluent.SchemaNested<A> editOrNewSchemaLike(V1CustomResourceValidation item);
    public Boolean isServed();
    public A withServed(Boolean served);
    public Boolean hasServed();
    public A withNewServed(String arg1);
    public A withNewServed(boolean arg1);
    public Boolean isStorage();
    public A withStorage(Boolean storage);
    public Boolean hasStorage();
    public A withNewStorage(String arg1);
    public A withNewStorage(boolean arg1);
    
/**
 * This method has been deprecated, please use method buildSubresources instead.
 * @return The buildable object.
 */
@Deprecated public V1CustomResourceSubresources getSubresources();
    public V1CustomResourceSubresources buildSubresources();
    public A withSubresources(V1CustomResourceSubresources subresources);
    public Boolean hasSubresources();
    public V1CustomResourceDefinitionVersionFluent.SubresourcesNested<A> withNewSubresources();
    public V1CustomResourceDefinitionVersionFluent.SubresourcesNested<A> withNewSubresourcesLike(V1CustomResourceSubresources item);
    public V1CustomResourceDefinitionVersionFluent.SubresourcesNested<A> editSubresources();
    public V1CustomResourceDefinitionVersionFluent.SubresourcesNested<A> editOrNewSubresources();
    public V1CustomResourceDefinitionVersionFluent.SubresourcesNested<A> editOrNewSubresourcesLike(V1CustomResourceSubresources item);
    public interface AdditionalPrinterColumnsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1CustomResourceColumnDefinitionFluent<V1CustomResourceDefinitionVersionFluent.AdditionalPrinterColumnsNested<N>> {

        public N and();
        public N endAdditionalPrinterColumn();    }


    public interface SchemaNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1CustomResourceValidationFluent<V1CustomResourceDefinitionVersionFluent.SchemaNested<N>> {

        public N and();
        public N endSchema();    }


    public interface SubresourcesNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1CustomResourceSubresourcesFluent<V1CustomResourceDefinitionVersionFluent.SubresourcesNested<N>> {

        public N and();
        public N endSubresources();    }


}
